rayoptics.gui package
=====================

.. automodule:: rayoptics.gui
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

.. toctree::
   :maxdepth: 4

   rayoptics.gui.actions
   rayoptics.gui.appcmds
   rayoptics.gui.appmanager
   rayoptics.gui.dashboards
   rayoptics.gui.roafile
   rayoptics.gui.util
